export declare type NonPromise<T> = T extends Promise<unknown> ? never : T;
export declare type NonFunction<T> = T extends Function ? never : T;
export declare type SetStateAction<Value> = NonFunction<Value> | ((prev: Value) => NonFunction<Value>);
export declare type Getter = <Value>(atom: Atom<Value>) => Value;
export declare type Setter = <Value, Update>(atom: WritableAtom<Value, Update>, update: Update) => void;
export declare type Atom<Value> = {
    init?: Value;
    read: (get: Getter) => Value | Promise<Value>;
};
export declare type WritableAtom<Value, Update> = Atom<Value> & {
    write: (get: Getter, set: Setter, update: Update) => void | Promise<void>;
};
export declare type PrimitiveAtom<Value> = WritableAtom<Value, SetStateAction<Value>>;
export declare type AnyAtom = Atom<unknown>;
export declare type AnyWritableAtom = WritableAtom<unknown, unknown>;
